from .buildutils_sno import is_expr
from colorama import Fore, init

init()


def calculate_simple(expression):
    if is_expr(expression) is False:
        return Fore.LIGHTRED_EX + 'Это не математическое выражение!' + Fore.RESET
    try:
        return Fore.LIGHTGREEN_EX + f'>>> {eval(expression)}' + Fore.RESET
    except ValueError:
        return Fore.LIGHTRED_EX + 'Ответ на выражение настолько большой, что лимит длины строки превышен!' + Fore.RESET
    except ZeroDivisionError:
        return Fore.LIGHTRED_EX + 'Нельзя делить на ноль!' + Fore.RESET
    except SyntaxError:
        return Fore.LIGHTRED_EX + 'Ошибка синтаксиса!' + Fore.RESET




from colorama import Fore, init
from .exceptions_all import NotMathsExpression
from .buildutils_sno import is_expr

init()


def calculate(expression):
    if is_expr(expression) is False:
        raise NotMathsExpression('Input data is not expression!')
    return eval(expression)


def calculate_simple(expression):
    if is_expr(expression) is False:
        return Fore.LIGHTRED_EX + '>>> Это не математическое выражение!'
    return Fore.LIGHTGREEN_EX + f'>>> {eval(expression)}'


# def calculate_exr(expression: str) -> str:
#     try:
#         return Fore.LIGHTGREEN_EX + f'>>> {evaluate(expression)}'
#     except KeyboardInterrupt:
#         return Fore.LIGHTYELLOW_EX + '\n>>> Программа остановлена.'
#     except TypeError:
#         return Fore.LIGHTRED_EX + '>>> Операция невыполнима! Это программа, а не выражение!'
#     except KeyError:
#         return Fore.LIGHTRED_EX + '>>> Процесс завершился ошибкой KeyError, значит, это не математическое выражение.'
#     except SyntaxError:
#         return '>>> Это программа, да к тому же, с ошибкой синтаксиса)'
#     except OverflowError:
#         return Fore.LIGHTRED_EX + '>>> У выражения слишком большой ответ...'



# from numexpr import evaluate
# from colorama import Fore, init
#
# init()
#
#
# def calculate_exr(expression: str) -> str:
#     try:
#         return Fore.LIGHTGREEN_EX + f'>>> {evaluate(expression)}'
#     except KeyboardInterrupt:
#         return Fore.LIGHTYELLOW_EX + '\n>>> Программа остановлена.'
#     except TypeError:
#         return Fore.LIGHTRED_EX + '>>> Операция невыполнима! Это программа, а не выражение!'
#     except KeyError:
#         return Fore.LIGHTRED_EX + '>>> Процесс завершился ошибкой KeyError, значит, это не математическое выражение.'
#     except SyntaxError:
#         return '>>> Это программа, да к тому же, с ошибкой синтаксиса)'
#     except OverflowError:
#         return Fore.LIGHTRED_EX + '>>> У выражения слишком большой ответ...'



def is_expr(expression: str) -> bool:
    can_expr = ['+', '-', '/', '*', '%', '**', ' ', '(', ')', '.']
    for i in can_expr:
        expression = expression.replace(i, '')
    if not expression.isdigit():
        return False
    return True



from .exceptions_all import NotMathsExpression
from .buildutils_sno import is_expr


def calculate(expression):
    if is_expr(expression) is False:
        raise NotMathsExpression('Input data is not expression!')
    return eval(expression)



from setuptools import setup

with open("README.md") as file:
    read_me_description = file.read()

setup(
    name="simple_num_operations",
    version="1.1",
    author="axeinstd",
    author_email="axeinthereal@gmail.com",
    description="This is a package to do some operations with numbers.",
    long_description=read_me_description,
    long_description_content_type="text/markdown",
    url="https://github.com/thedotaxein/simplenumoperations",
    packages=['simple_num_operations'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'colorama',
    ],
    python_requires='>=3.9',
)
